@@ -1,5 +1,7 @@
 from collections.abc import Iterable, Callable
 from typing import List
+
+from pyparsing import Diagnostics
 from data_product_sdk.cortex_databricks.data_platform.aws_utils import S3
 from data_product_sdk.cortex_databricks.data_platform.databricks_utils import (
     reset_autoloader_checkpoint,
@@ -126,7 +128,8 @@ def build_table_path(bucket_name: str, data_pack_name: str, dataset_name: str):
         BRONZE_BUCKET,
         SILVER_BUCKET,
         GOLD_BUCKET,
-    ), f"bucket name must be one of {BRONZE_BUCKET}, {SILVER_BUCKET} or {GOLD_BUCKET}"
+        DIAMOND_BUCKET
+    ), f"bucket name must be one of {BRONZE_BUCKET}, {SILVER_BUCKET}, {GOLD_BUCKET} or {DIAMOND_BUCKET}"
     table_location = f"s3a://{bucket_name}/{data_pack_name}/{dataset_name}"
 
     return table_location
@@ -143,8 +146,8 @@ def build_checkpoint_path(
     :return:
     """
     assert bucket_name == BRONZE_BUCKET or (
-        input_table_name and bucket_name in (SILVER_BUCKET, GOLD_BUCKET)
-    ), f"bucket name must be one of {BRONZE_BUCKET}, {SILVER_BUCKET} or {GOLD_BUCKET} and {input_table_name} must be valid when using {SILVER_BUCKET} or {GOLD_BUCKET}"
+        input_table_name and bucket_name in (SILVER_BUCKET, GOLD_BUCKET, DIAMOND_BUCKET)
+    ), f"bucket name must be one of {BRONZE_BUCKET}, {SILVER_BUCKET}, {GOLD_BUCKET} or {DIAMOND_BUCKET} and {input_table_name} must be valid when using {SILVER_BUCKET}, {GOLD_BUCKET} or {DIAMOND_BUCKET}"
     checkpoint_location = f"s3://{bucket_name}/_databricks_autoloader_checkpoints/{data_pack_name}/{dataset_name}/{input_table_name}"
 
     return checkpoint_location
